@@ -5,7 +5,6 @@ import com.unciv.GUI
 import com.unciv.UncivGame
 import com.unciv.UncivGame.Version
 import com.unciv.json.json
-import com.unciv.logic.BackwardCompatibility.convertEncampmentData
 import com.unciv.logic.BackwardCompatibility.convertFortify
 import com.unciv.logic.BackwardCompatibility.guaranteeUnitPromotions
 import com.unciv.logic.BackwardCompatibility.migrateGreatPersonPools
@@ -581,7 +580,7 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
 
         // Cater for the mad modder using trailing '-' in their repo name - convert the mods list so
         // it requires our new, Windows-safe local name (no trailing blanks)
-        for ((oldName, newName) in gameParameters.mods.map { it to it.repoNameToFolderName() }) {
+        for ((oldName, newName) in gameParameters.mods.map { it to it.repoNameToFolderName(onlyOuterBlanks = true) }) {
             if (newName == oldName) continue
             gameParameters.mods.remove(oldName)
             gameParameters.mods.add(newName)
@@ -642,7 +641,6 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
             .flatMap { it.getResourceRequirementsPerTurn().keys })
         spaceResources.addAll(ruleset.victories.values.flatMap { it.requiredSpaceshipParts })
 
-        convertEncampmentData()
         barbarians.setTransients(this)
 
         cityDistances.game = this
