@@ -227,7 +227,7 @@ object GameStarter {
         val ruleSet = gameInfo.ruleset
         val startingEra = gameInfo.gameParameters.startingEra
         val era = ruleSet.eras[startingEra]!!
-        for (civInfo in gameInfo.civilizations.filter { !it.isBarbarian() }) {
+        for (civInfo in gameInfo.civilizations.filter { !it.isBarbarian() && !it.isSpectator() }) {
             civInfo.addGold((era.startingGold * gameInfo.speed.goldCostModifier).toInt())
             civInfo.policies.addCulture((era.startingCulture * gameInfo.speed.cultureCostModifier).toInt())
         }
@@ -404,7 +404,7 @@ object GameStarter {
             if (tile.improvement != null
                 && tile.getTileImprovement()!!.isAncientRuinsEquivalent()
             ) {
-                tile.changeImprovement(null) // Remove ancient ruins in immediate vicinity
+                tile.removeImprovement() // Remove ancient ruins in immediate vicinity
             }
         }
     }
@@ -435,7 +435,7 @@ object GameStarter {
     }
 
     private fun getStartingUnitsForEraAndDifficulty(civ: Civilization, gameInfo: GameInfo, ruleset: Ruleset, startingEra: String): MutableList<String> {
-        val startingUnits = ruleset.eras[startingEra]!!.getStartingUnits().toMutableList()
+        val startingUnits = ruleset.eras[startingEra]!!.getStartingUnits(ruleset)
 
         // Add extra units granted by difficulty
         startingUnits.addAll(when {
