@@ -9,7 +9,6 @@ import com.unciv.logic.civilization.AlertType
 import com.unciv.logic.civilization.NotificationCategory
 import com.unciv.logic.civilization.NotificationIcon
 import com.unciv.logic.civilization.PopupAlert
-import com.unciv.logic.map.mapunit.MapUnit
 import com.unciv.logic.map.tile.Tile
 import com.unciv.logic.multiplayer.isUsersTurn
 import com.unciv.models.ruleset.Building
@@ -21,8 +20,8 @@ import com.unciv.models.ruleset.Ruleset
 import com.unciv.models.ruleset.unique.LocalUniqueCache
 import com.unciv.models.ruleset.unique.StateForConditionals
 import com.unciv.models.ruleset.unique.UniqueMap
-import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unique.UniqueTriggerActivation
+import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.stats.Stat
 import com.unciv.models.stats.Stats
@@ -32,7 +31,6 @@ import com.unciv.ui.components.extensions.withItem
 import com.unciv.ui.components.extensions.withoutItem
 import com.unciv.ui.screens.civilopediascreen.CivilopediaCategories
 import com.unciv.ui.screens.civilopediascreen.FormattedLine
-import com.unciv.ui.screens.worldscreen.unit.actions.UnitActions
 import kotlin.math.ceil
 import kotlin.math.min
 import kotlin.math.roundToInt
@@ -494,12 +492,11 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         builtBuildings.add(buildingName)
 
         city.civ.cache.updateCitiesConnectedToCapital(false) // could be a connecting building, like a harbor
-        city.civ.cache.updateCivResources() // this building could be a resource-requiring one
 
         /** Support for [UniqueType.CreatesOneImprovement] */
         applyCreateOneImprovement(building)
 
-        addFreeBuildings()
+
 
         triggerNewBuildingUniques(building)
 
@@ -515,8 +512,10 @@ class CityConstructions : IsPartOfGameInfoSerialization {
             UniqueType.StatPercentFromObject, UniqueType.AllStatsPercentFromObject
         )
 
+        updateUniques()
+
         // Happiness is global, so it could affect all cities
-        if(building.isStatRelated(Stat.Happiness)) {
+        if (building.isStatRelated(Stat.Happiness)) {
             for (city in civ.cities) {
                 city.reassignPopulationDeferred()
             }
@@ -524,7 +523,7 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         else if(uniqueTypesModifyingYields.any { building.hasUnique(it) })
             city.reassignPopulationDeferred()
 
-        updateUniques()
+        addFreeBuildings()
     }
 
     fun triggerNewBuildingUniques(building: Building) {
@@ -534,9 +533,9 @@ class CityConstructions : IsPartOfGameInfoSerialization {
             if (!unique.hasTriggerConditional())
                 UniqueTriggerActivation.triggerCivwideUnique(unique, city.civ, city, triggerNotificationText = triggerNotificationText)
 
-            for (unique in city.civ.getTriggeredUniques(UniqueType.TriggerUponConstructingBuilding, StateForConditionals(city.civ, city)))
-                if (unique.conditionals.any {it.type == UniqueType.TriggerUponConstructingBuilding && building.matchesFilter(it.params[0])})
-                    UniqueTriggerActivation.triggerCivwideUnique(unique, city.civ, city, triggerNotificationText = triggerNotificationText)
+        for (unique in city.civ.getTriggeredUniques(UniqueType.TriggerUponConstructingBuilding, StateForConditionals(city.civ, city)))
+            if (unique.conditionals.any {it.type == UniqueType.TriggerUponConstructingBuilding && building.matchesFilter(it.params[0])})
+                UniqueTriggerActivation.triggerCivwideUnique(unique, city.civ, city, triggerNotificationText = triggerNotificationText)
 
         for (unique in city.civ.getTriggeredUniques(UniqueType.TriggerUponConstructingBuildingCityFilter, StateForConditionals(city.civ, city)))
             if (unique.conditionals.any {it.type == UniqueType.TriggerUponConstructingBuildingCityFilter
@@ -552,7 +551,6 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         else builtBuildingObjects.removeAll{ it.name == buildingName }
         builtBuildings.remove(buildingName)
         city.civ.cache.updateCitiesConnectedToCapital(false) // could be a connecting building, like a harbor
-        city.civ.cache.updateCivResources() // this building could be a resource-requiring one
         updateUniques()
     }
 
@@ -560,7 +558,10 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         builtBuildingUniqueMap.clear()
         for (building in getBuiltBuildings())
             builtBuildingUniqueMap.addUniques(building.uniqueObjects)
-        if (!onLoadGame) city.cityStats.update()
+        if (!onLoadGame) {
+            city.cityStats.update()
+            city.civ.cache.updateCivResources()
+        }
     }
 
     fun addFreeBuildings() {
@@ -749,13 +750,15 @@ class CityConstructions : IsPartOfGameInfoSerialization {
         } else true // we're just continuing the regular queue
     }
 
-    fun raisePriority(constructionQueueIndex: Int) {
+    fun raisePriority(constructionQueueIndex: Int): Int {
         constructionQueue.swap(constructionQueueIndex - 1, constructionQueueIndex)
+        return constructionQueueIndex - 1
     }
 
     // Lowering == Highering next element in queue
-    fun lowerPriority(constructionQueueIndex: Int) {
+    fun lowerPriority(constructionQueueIndex: Int): Int {
         raisePriority(constructionQueueIndex + 1)
+        return constructionQueueIndex + 1
     }
 
     private fun MutableList<String>.swap(idx1: Int, idx2: Int) {
@@ -769,17 +772,14 @@ class CityConstructions : IsPartOfGameInfoSerialization {
      *  If [building] is an improvement-creating one, find a marked tile matching the improvement to be created
      *  (skip if none found), then un-mark the tile and place the improvement unless [removeOnly] is set.
      */
-    fun applyCreateOneImprovement(building: Building, removeOnly: Boolean = false) {
+    private fun applyCreateOneImprovement(building: Building, removeOnly: Boolean = false) {
         val improvement = building.getImprovementToCreate(city.getRuleset())
             ?: return
         val tileForImprovement = getTileForImprovement(improvement.name) ?: return
         tileForImprovement.stopWorkingOnImprovement()  // clears mark
         if (removeOnly) return
-        /**todo unify with [UnitActions.getImprovementConstructionActions] and [MapUnit.workOnImprovement] - this won't allow e.g. a building to place a road */
-        tileForImprovement.changeImprovement(improvement.name)
+        tileForImprovement.changeImprovement(improvement.name, city.civ)
         city.civ.lastSeenImprovement[tileForImprovement.position] = improvement.name
-        city.cityStats.update()
-        city.civ.cache.updateCivResources()
         // If bought the worldscreen will not have been marked to update, and the new improvement won't show until later...
         GUI.setUpdateWorldOnNextRender()
     }
@@ -791,11 +791,11 @@ class CityConstructions : IsPartOfGameInfoSerialization {
      */
     fun removeCreateOneImprovementConstruction(improvement: String) {
         val ruleset = city.getRuleset()
-        val indexToRemove = constructionQueue.withIndex().mapNotNull {
+        val indexToRemove = constructionQueue.withIndex().firstNotNullOfOrNull {
             val construction = getConstruction(it.value)
             val buildingImprovement = (construction as? Building)?.getImprovementToCreate(ruleset)?.name
             it.index.takeIf { buildingImprovement == improvement }
-        }.firstOrNull() ?: return
+        } ?: return
 
         constructionQueue.removeAt(indexToRemove)
 
