@@ -53,7 +53,7 @@ class CityFounder {
         })
             tile.removeTerrainFeature(terrainFeature)
 
-        tile.changeImprovement(null)
+        tile.removeImprovement()
         tile.improvementInProgress = null
 
         val ruleset = civInfo.gameInfo.ruleset
