@@ -26,8 +26,9 @@ import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorOptionsTab
 import com.unciv.ui.popups.ConfirmPopup
 import com.unciv.ui.components.tilegroups.TileGroup
 import com.unciv.ui.screens.basescreen.BaseScreen
-import com.unciv.ui.components.KeyCharAndCode
-import com.unciv.ui.components.KeyboardPanningListener
+import com.unciv.ui.components.input.KeyCharAndCode
+import com.unciv.ui.components.input.KeyShortcutDispatcherVeto
+import com.unciv.ui.components.input.KeyboardPanningListener
 import com.unciv.ui.images.ImageWithCustomSize
 import com.unciv.ui.popups.ToastPopup
 import com.unciv.ui.screens.basescreen.RecreateOnResize
@@ -41,7 +42,6 @@ import kotlinx.coroutines.Job
 
 //todo normalize properly
 
-//todo Remove "Area: [amount] tiles, [amount2] continents/islands = " after 2022-07-01
 //todo functional Tab for Units (empty Tab is prepared but commented out in MapEditorEditTab.AllEditSubTabs)
 //todo copy/paste tile areas? (As tool tab, brush sized, floodfill forbidden, tab displays copied area)
 //todo Synergy with Civilopedia for drawing loose tiles / terrain icons
@@ -206,6 +206,9 @@ class MapEditorScreen(map: TileMap? = null): BaseScreen(), RecreateOnResize {
         return newHolder
     }
 
+    // We contain a map...
+    override fun getShortcutDispatcherVetoer() = KeyShortcutDispatcherVeto.createTileGroupMapDispatcherVetoer()
+
     fun loadMap(map: TileMap, newRuleset: Ruleset? = null, selectPage: Int = 0) {
         clearOverlayImages()
         mapHolder.remove()
