@@ -158,8 +158,7 @@ object UnitActions {
 
         return UnitAction(UnitActionType.Create, "Create [$improvementName]",
             action = {
-                tile.changeImprovement(improvementName)
-                tile.getTileImprovement()!!.handleImprovementCompletion(unit)
+                tile.changeImprovement(improvementName, unit.civ)
                 unit.destroy()  // Modders may wish for a nondestructive way, but that should be another Unique
             }.takeIf { unit.currentMovement > 0 })
     }
@@ -492,10 +491,7 @@ object UnitActions {
                 title = actionTextWithSideEffects("Create [$improvementName]", unique, unit),
                 action = {
                     val unitTile = unit.getTile()
-                    unitTile.improvementFunctions.removeCreatesOneImprovementMarker()
-                    unitTile.changeImprovement(improvementName)
-                    unitTile.stopWorkingOnImprovement()
-                    improvement.handleImprovementCompletion(unit)
+                    unitTile.changeImprovement(improvementName, unit.civ)
 
                     // without this the world screen won't show the improvement because it isn't the 'last seen improvement'
                     unit.civ.cache.updateViewableTiles()
@@ -514,7 +510,7 @@ object UnitActions {
         return finalActions
     }
 
-    fun takeOverTilesAround(unit: MapUnit) {
+    fun takeOverTilesAround(civ: Civilization, tile: Tile) {
         // This method should only be called for a citadel - therefore one of the neighbour tile
         // must belong to unit's civ, so minByOrNull in the nearestCity formula should be never `null`.
         // That is, unless a mod does not specify the proper unique - then fallbackNearestCity will take over.
@@ -524,39 +520,39 @@ object UnitActions {
             return city.getCenterTile().aerialDistanceTo(tile) +
                     (if (city.isBeingRazed) 5 else 0)
         }
-        fun fallbackNearestCity(unit: MapUnit) =
-            unit.civ.cities.minByOrNull {
-               it.getCenterTile().aerialDistanceTo(unit.currentTile) +
+        fun fallbackNearestCity(civ: Civilization, tile: Tile) =
+            civ.cities.minByOrNull {
+               it.getCenterTile().aerialDistanceTo(tile) +
                    (if (it.isBeingRazed) 5 else 0)
             }!!
 
         // In the rare case more than one city owns tiles neighboring the citadel
         // this will prioritize the nearest one not being razed
-        val nearestCity = unit.currentTile.neighbors
-            .filter { it.getOwner() == unit.civ }
+        val nearestCity = tile.neighbors
+            .filter { it.getOwner() == civ }
             .minByOrNull { priority(it) }?.getCity()
-            ?: fallbackNearestCity(unit)
+            ?: fallbackNearestCity(civ, tile)
 
         // capture all tiles which do not belong to unit's civ and are not enemy cities
         // we use getTilesInDistance here, not neighbours to include the current tile as well
-        val tilesToTakeOver = unit.currentTile.getTilesInDistance(1)
-                .filter { !it.isCityCenter() && it.getOwner() != unit.civ }
+        val tilesToTakeOver = tile.getTilesInDistance(1)
+                .filter { !it.isCityCenter() && it.getOwner() != civ }
 
         val civsToNotify = mutableSetOf<Civilization>()
-        for (tile in tilesToTakeOver) {
-            val otherCiv = tile.getOwner()
+        for (tileToTakeOver in tilesToTakeOver) {
+            val otherCiv = tileToTakeOver.getOwner()
             if (otherCiv != null) {
                 // decrease relations for -10 pt/tile
-                if (!otherCiv.knows(unit.civ)) otherCiv.diplomacyFunctions.makeCivilizationsMeet(unit.civ)
-                otherCiv.getDiplomacyManager(unit.civ).addModifier(DiplomaticModifiers.StealingTerritory, -10f)
+                if (!otherCiv.knows(civ)) otherCiv.diplomacyFunctions.makeCivilizationsMeet(civ)
+                otherCiv.getDiplomacyManager(civ).addModifier(DiplomaticModifiers.StealingTerritory, -10f)
                 civsToNotify.add(otherCiv)
             }
-            nearestCity.expansion.takeOwnership(tile)
+            nearestCity.expansion.takeOwnership(tileToTakeOver)
         }
 
         for (otherCiv in civsToNotify)
-            otherCiv.addNotification("Your territory has been stolen by [${unit.civ}]!",
-                unit.currentTile.position, NotificationCategory.Cities, unit.civ.civName, NotificationIcon.War)
+            otherCiv.addNotification("Your territory has been stolen by [$civ]!",
+                tile.position, NotificationCategory.Cities, civ.civName, NotificationIcon.War)
     }
 
     private fun addFortifyActions(actionList: ArrayList<UnitAction>, unit: MapUnit, showingAdditionalActions: Boolean) {
@@ -634,6 +630,9 @@ object UnitActions {
         // If gifting to major civ they need to be friendly
         else if (!tile.isFriendlyTerritory(unit.civ)) return null
 
+        // Transported units can't be gifted
+        if (unit.isTransported) return null
+
         if (unit.currentMovement <= 0)
             return UnitAction(UnitActionType.GiftUnit, action = null)
 
